# Configuring SSO with SAP Cloud Identity Services - Identity Authentication Service (IAS)
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#prerequisites)
  * [Step 1: Get SSO Metadata from IAS](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#step-1:-get-sso-metadata-from-ias)
  * [Step 2: Create a SAML Application](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#step-2:-create-a-saml-application)
  * [Step 3: Configure SAML Settings](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#step-3:-configure-saml-settings)
  * [Step 4: Configure Attribute Mapping](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#step-4:-configure-attribute-mapping)
  * [(Optional) Step 5: Configure Role Attributes](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#\(optional\)-step-5:-configure-role-attributes)
  * [Step 6: Verify SSO Configuration](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias#step-6:-verify-sso-configuration)


Configure single sign-on (SSO) with SAP Cloud Identity Services - Identity Authentication service (IAS) as identity provider to enhance security and simplify user authentication.
